==> midori-0.0.8.tar.gz: midori-0.0.8/src/document.h <==
/* Copyright (C) 2007 Christian Dywan <christian at twotoasts dot de>

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA. */

#ifndef __DOCUMENT_H__
#define __DOCUMENT_H__ 1

#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>
#include "browser.h"
#include "sokoke.h"
#include "midori.h"
#include "config.h"
#include "debug.h"

#ifdef MIDORI_WEBI
 #include <webi/webi.h>
#elif defined(MIDORI_WEBKIT)
 #include <webkitgtkpage.h>
 #include <webkitgtkglobal.h>
#endif

void on_document_location_changed(GtkWidget*
#ifdef MIDORI_WEBKIT
 , const gchar*
#endif
, CBrowser*);

void on_document_title_changed(GtkWidget*
#ifdef MIDORI_WEBKIT
 , const gchar*, const gchar*
#endif
 , CBrowser*);

#ifdef MIDORI_WEBKIT
void on_frame_title_changed(WebKitGtkFrame*, const gchar*, const gchar*
 , CBrowser*);

void on_document_icon_changed(GtkWidget*, WebKitGtkFrame*, CBrowser*);
#endif

void on_document_load_started(GtkWidget*
#ifdef MIDORI_WEBKIT
 , WebKitGtkFrame*
#endif
, CBrowser*);

void on_document_load_changed(GtkWidget*
#ifdef MIDORI_WEBKIT
 , gint progress
#else
 , const WebiLoadStatus*
#endif
 , CBrowser*);

void on_document_load_finished(GtkWidget*
#ifdef MIDORI_WEBKIT
 , WebKitGtkFrame*
#endif
, CBrowser*);

#ifdef MIDORI_WEBKIT
void on_frame_cleared(WebKitGtkFrame*, CBrowser*);

void on_frame_load_done(WebKitGtkFrame*, gboolean, CBrowser*);
#endif

void on_document_status_message(GtkWidget*, gchar*, CBrowser*);

void on_document_selection_changed(GtkWidget*, CBrowser*);

void on_document_request_script_prompt(GtkWidget*
#ifdef MIDORI_WEBI
 , WebiPromptArgs* args
#endif
 , CBrowser* browser);

void on_document_request_auth_prompt(GtkWidget*
#ifdef MIDORI_WEBI
 , WebiAuthArgs*
#endif
 , CBrowser*);

gboolean on_document_set_cookie(GtkWidget*
#ifdef MIDORI_WEBI
 , WebiCookie*
#endif
 , CBrowser*);

void on_document_link_hover(GtkWidget*, const gchar*, const gchar*
 , const gchar*, const gchar*, CBrowser*);

GtkWidget* on_document_window_open(GtkWidget*, const gchar*, CBrowser*);

void on_document_window_features(GtkWidget*
#ifdef MIDORI_WEBI
 , WebiWindowProperties*
#endif
 , CBrowser*);

void document_load_uri(GtkWidget*, const gchar*);

void document_go_back(GtkWidget*);

void document_go_forward(GtkWidget*);

void document_refresh(GtkWidget*, gboolean);

void document_stop(GtkWidget*);

gboolean document_can_go_back(GtkWidget*);

gboolean document_can_go_forward(GtkWidget*);

G_CONST_RETURN gchar* document_get_uri(GtkWidget*);

G_CONST_RETURN gchar* document_get_title(GtkWidget*);

gboolean document_find(GtkWidget*, const gchar*, gboolean, gboolean);

gboolean document_can_increase_text_size(GtkWidget*);

gboolean document_can_decrease_text_size(GtkWidget*);

void document_set_text_size(GtkWidget*, gfloat);

gfloat document_get_text_size(GtkWidget*);

void document_close(GtkWidget*, CBrowser*);

#endif /* !__DOCUMENT_H__ */

==> midori-0.0.10.tar.gz: midori-0.0.10/src/document.h <==
/* Copyright (C) 2007 Christian Dywan <christian at twotoasts dot de>

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA. */

#ifndef __DOCUMENT_H__
#define __DOCUMENT_H__ 1

#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>
#include "ui.h"
#include "browser.h"
#include "sokoke.h"
#include "debug.h"

#ifdef MIDORI_WEBI
 #include <webi/webi.h>
#elif defined(MIDORI_WEBKIT)
 #include <webkitgtkpage.h>
 #include <webkitgtkglobal.h>
#endif

void on_document_location_changed(GtkWidget*
#ifdef MIDORI_WEBKIT
 , const gchar*
#endif
, CBrowser*);

void on_document_title_changed(GtkWidget*
#ifdef MIDORI_WEBKIT
 , const gchar*, const gchar*
#endif
 , CBrowser*);

#ifdef MIDORI_WEBKIT
void on_frame_title_changed(WebKitFrame*, const gchar*, const gchar*
 , CBrowser*);

void on_document_icon_changed(GtkWidget*, WebKitFrame*, CBrowser*);
#endif

void on_document_load_started(GtkWidget*
#ifdef MIDORI_WEBKIT
 , WebKitFrame*
#endif
, CBrowser*);

void on_document_load_changed(GtkWidget*
#ifdef MIDORI_WEBKIT
 , gint progress
#else
 , const WebiLoadStatus*
#endif
 , CBrowser*);

void on_document_load_finished(GtkWidget*
#ifdef MIDORI_WEBKIT
 , WebKitFrame*
#endif
, CBrowser*);

#ifdef MIDORI_WEBKIT
void on_frame_cleared(WebKitFrame*, CBrowser*);

void on_frame_load_done(WebKitFrame*, gboolean, CBrowser*);
#endif

void on_document_status_message(GtkWidget*, gchar*, CBrowser*);

void on_document_selection_changed(GtkWidget*, CBrowser*);

void on_document_request_script_prompt(GtkWidget*
#ifdef MIDORI_WEBI
 , WebiPromptArgs* args
#endif
 , CBrowser* browser);

void on_document_request_auth_prompt(GtkWidget*
#ifdef MIDORI_WEBI
 , WebiAuthArgs*
#endif
 , CBrowser*);

gboolean on_document_set_cookie(GtkWidget*
#ifdef MIDORI_WEBI
 , WebiCookie*
#endif
 , CBrowser*);

void on_document_link_hover(GtkWidget*, const gchar*
#ifdef MIDORI_WEBI
 , const gchar*
#endif
 , const gchar*
#ifdef MIDORI_WEBI
 , const gchar*
#endif
 , CBrowser*);

GtkWidget* on_document_window_open(GtkWidget*, const gchar*, CBrowser*);

void on_document_window_features(GtkWidget*
#ifdef MIDORI_WEBI
 , WebiWindowProperties*
#endif
 , CBrowser*);

gboolean on_document_mouse_down(GtkWidget*, GdkEventButton*, CBrowser*);

void on_document_popup(GtkWidget*, CBrowser*);

gboolean on_document_scroll(GtkWidget*, GdkEventScroll*, CBrowser*);

void on_document_destroy(GtkWidget*, CBrowser*);

void document_load_uri(GtkWidget*, const gchar*);

void document_go_back(GtkWidget*);

void document_go_forward(GtkWidget*);

void document_refresh(GtkWidget*, gboolean);

void document_stop(GtkWidget*);

gboolean document_can_go_back(GtkWidget*);

gboolean document_can_go_forward(GtkWidget*);

G_CONST_RETURN gchar* document_get_uri(GtkWidget*);

G_CONST_RETURN gchar* document_get_title(GtkWidget*);

gboolean document_find(GtkWidget*, const gchar*, gboolean, gboolean);

gboolean document_can_increase_text_size(GtkWidget*);

gboolean document_can_decrease_text_size(GtkWidget*);

void document_set_text_size(GtkWidget*, gfloat);

gfloat document_get_text_size(GtkWidget*);

gboolean on_document_leave(GtkWidget*, GdkEventCrossing*, CBrowser*);

void document_close(GtkWidget*, CBrowser*);

#endif /* !__DOCUMENT_H__ */
